@@ -1,13 +1,18 @@
 import dataclasses
-from typing import Set, List, Dict
+from typing import Set, List, Dict, Optional, Union
 
 from jig.visualizer.module_dependency.domain.model.master_graph import MasterGraph
 from jig.visualizer.module_dependency.domain.value.cluster import Cluster
 from jig.visualizer.module_dependency.domain.value.module_edge import (
     ModuleEdge,
     ModuleEdgeCollection,
+    ModuleEdgeStyle,
 )
-from jig.visualizer.module_dependency.domain.value.module_node import ModuleNode
+from jig.visualizer.module_dependency.domain.value.module_node import (
+    ModuleNode,
+    ModuleNodeStyle,
+)
+from jig.visualizer.module_dependency.domain.value.penwidth import Color, PenWidth
 
 
 @dataclasses.dataclass
@@ -17,6 +22,26 @@ class Graph:
     edges: Set[ModuleEdge] = dataclasses.field(default_factory=set)
     clusters: Dict[ModuleNode, Cluster] = dataclasses.field(default_factory=dict)
 
+    def to_dict(self) -> dict:
+        nodes = sorted([n.name for n in self.nodes])
+        edges = sorted([(e.tail.name, e.head.name) for e in self.edges])
+        clusters = dict(
+            [(node.name, cluster.to_dict()) for node, cluster in self.clusters.items()]
+        )
+
+        return {"nodes": nodes, "edges": edges, "clusters": clusters}
+
+    def find_node_owner(self, node: ModuleNode) -> Optional[Union["Graph", Cluster]]:
+        for cluster in self.clusters.values():
+            owner = cluster.find_node_owner(node)
+            if owner:
+                return owner
+
+        if node in self.nodes:
+            return self
+
+        return None
+
     def add_node(self, node: ModuleNode):
         self.nodes.add(node)
 
@@ -67,6 +92,23 @@ class Graph:
         for cluster in self.clusters.values():
             cluster.hide_node(node)
 
+    def style(self, node: ModuleNode, color: Color, penwidth: PenWidth):
+        node_style = ModuleNodeStyle(
+            color=color, fontcolor=color, fillcolor=Color.White, penwidth=penwidth
+        )
+        edge_style = ModuleEdgeStyle(
+            color=color, fontcolor=color, labelfontcolor=color, penwidth=penwidth
+        )
+
+        if node in self.nodes:
+            self.nodes.remove(node)
+            self.nodes.add(node.with_style(style=node_style))
+
+        edges = list(filter(lambda e: e.has_node(node), self.edges))
+        for edge in edges:
+            self.edges.remove(edge)
+            self.edges.add(edge.with_style(style=edge_style))
+
     def successors(self, node: ModuleNode) -> List[ModuleNode]:
         return [e.head for e in self.edges if e.tail == node]
 
@@ -74,12 +116,16 @@ class Graph:
         return [e.tail for e in self.edges if e.head == node]
 
     def dig(self, node: ModuleNode):
+        node_owner = self.find_node_owner(node)
+        if not node_owner:
+            raise ValueError(f"指定されたモジュール {node.name} が存在しません。")
+
         next_path_level = node.path_level + 1
 
         self._dig_successors(node, next_path_level)
         self._dig_predecessors(node, next_path_level)
         self._dig_inner_edge(node, next_path_level)
-        self._dig_clustering(node, next_path_level)
+        self._dig_clustering(node, next_path_level, node_owner)
 
         self.remove_node(node)
 
@@ -87,12 +133,17 @@ class Graph:
         for edge in self.master_graph.find_edges(node):
             self.add_edge(edge.limit_path_level(next_path_level))
 
-    def _dig_clustering(self, node: ModuleNode, next_path_level: int):
+    def _dig_clustering(
+        self,
+        node: ModuleNode,
+        next_path_level: int,
+        node_owner: Union["Graph", Cluster],
+    ):
         cluster = Cluster(node=node)
         for n in self.master_graph.find_nodes(node):
             cluster.add(n.limit_path_level(next_path_level))
 
-        self.add_cluster(cluster)
+        node_owner.add_cluster(cluster)
 
     def _dig_successors(self, node: ModuleNode, next_path_level: int):
         # 現在のnodeからの接続先エッジを取得
